scipy.interpolate.PiecewisePolynomial
=====================================

.. currentmodule:: scipy.interpolate

.. autoclass:: PiecewisePolynomial

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         PiecewisePolynomial.__call__
         PiecewisePolynomial.append
         PiecewisePolynomial.derivative
         PiecewisePolynomial.derivatives
         PiecewisePolynomial.extend



   

